ipecharts.option package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ipecharts.option.datazoomitems
   ipecharts.option.mediaitems
   ipecharts.option.seriesitems
   ipecharts.option.visualmapitems

Submodules
----------

.. toctree::
   :maxdepth: 4

   ipecharts.option.angleaxis
   ipecharts.option.aria
   ipecharts.option.axispointer
   ipecharts.option.basewidget
   ipecharts.option.brush
   ipecharts.option.calendar
   ipecharts.option.dataset
   ipecharts.option.datazoom
   ipecharts.option.geo
   ipecharts.option.geo3d
   ipecharts.option.globe
   ipecharts.option.graphic
   ipecharts.option.grid
   ipecharts.option.grid3d
   ipecharts.option.legend
   ipecharts.option.mapbox3d
   ipecharts.option.matrix
   ipecharts.option.media
   ipecharts.option.option
   ipecharts.option.parallel
   ipecharts.option.parallelaxis
   ipecharts.option.polar
   ipecharts.option.radar
   ipecharts.option.radiusaxis
   ipecharts.option.series
   ipecharts.option.singleaxis
   ipecharts.option.stateanimation
   ipecharts.option.textstyle
   ipecharts.option.thumbnail
   ipecharts.option.timeline
   ipecharts.option.title
   ipecharts.option.toolbox
   ipecharts.option.tooltip
   ipecharts.option.visualmap
   ipecharts.option.xaxis
   ipecharts.option.xaxis3d
   ipecharts.option.yaxis
   ipecharts.option.yaxis3d
   ipecharts.option.zaxis3d

Module contents
---------------

.. automodule:: ipecharts.option
   :members:
   :show-inheritance:
   :undoc-members:
